@@ -8,7 +8,7 @@
 ! the maximum number of denominators    !
 ! (it can be changed by the user)       ! 
 !                                       !
-  integer, public, parameter :: maxden= 6
+  integer, public, parameter :: maxden= 8
  end module maxnumden
 ! 
  module mbnvalues
@@ -46,7 +46,9 @@
     do k= 1,maxden
      nbn1(k)= comb(k,n1)
     enddo
+    ierr= -1
     allocate  (bn1(1:maxden,maxden,nbn1(maxden)), stat=ierr)
+    if (ierr.ne.0) STOP "Not enough memory to allocate bn1"
     bn1= -1
     do kden= 1,maxden
      kcount= 0
@@ -68,7 +70,9 @@
     do k= 2,maxden
      nbn2(k)= comb(k,n2)
     enddo
+    ierr= -1
     allocate  (bn2(2:maxden,maxden,nbn2(maxden)), stat=ierr)
+    if (ierr.ne.0) STOP "Not enough memory to allocate bn2"
     bn2= -1
     do kden= 2,maxden
      kcount= 0
@@ -91,7 +95,9 @@
     do k= 3,maxden
      nbn3(k)= comb(k,n3)
     enddo
+    ierr= -1
     allocate  (bn3(3:maxden,maxden,nbn3(maxden)), stat=ierr)
+    if (ierr.ne.0) STOP "Not enough memory to allocate bn3"
     bn3= -1
     do kden= 3,maxden
      kcount= 0
@@ -115,7 +121,9 @@
     do k= 4,maxden
      nbn4(k)= comb(k,n4)
     enddo
+    ierr= -1
     allocate  (bn4(4:maxden,maxden,nbn4(maxden)), stat=ierr)
+    if (ierr.ne.0) STOP "Not enough memory to allocate bn4"
     bn4= -1
     do kden= 4,maxden
      kcount= 0
@@ -221,7 +229,6 @@
   integer, public, dimension(:,:), allocatable :: bbn3
   integer, public, dimension(:,:), allocatable :: bbn4
   public load_dimensions
-  public load_local_dimensions
   contains
 ! 
   subroutine load_dimensions
@@ -232,23 +239,4 @@
   dmns_c= nbn3(dmns)
   dmns_d= nbn4(dmns)
   end subroutine
-! 
-  subroutine load_local_dimensions(np)
-  integer, intent(in) :: np
-  integer :: ierr,i,j
-  dmns_1= nbn1(np)
-  dmns_2= nbn2(np)
-  dmns_3= nbn3(np)
-  dmns_4= nbn4(np)
-  allocate  (bbn1(np,dmns_1), stat=ierr)
-  allocate  (bbn2(np,dmns_2), stat=ierr)
-  allocate  (bbn3(np,dmns_3), stat=ierr)
-  allocate  (bbn4(np,dmns_4), stat=ierr)
-  do i= 1,np  
-    do j= 1,dmns_1; bbn1(i,j)= bn1(np,i,j); enddo
-    do j= 1,dmns_2; bbn2(i,j)= bn2(np,i,j); enddo
-    do j= 1,dmns_3; bbn3(i,j)= bn3(np,i,j); enddo
-    do j= 1,dmns_4; bbn4(i,j)= bn4(np,i,j); enddo
-  enddo
-  end subroutine
  end module dimensions 
